==> constructorio-ui-quizzes-1.5.0.tgz: package/lib/mjs/components/ResultContainer/ResultContainer.js <==
import React, { useContext } from 'react';
import RedoButton from '../RedoButton/RedoButton';
import QuizContext from '../CioQuiz/context';
import ResultFilters from '../ResultFilters/ResultFilters';
import ZeroResults from '../ZeroResults/ZeroResults';
import Results from '../Results/Results';
import Spinner from '../Spinner/Spinner';
export default function ResultContainer(props) {
    const { options } = props;
    const { resultCardSalePriceKey, resultCardRegularPriceKey, resultCardRatingCountKey, resultCardRatingScoreKey, renderResultCardPriceDetails, } = options;
    const { state } = useContext(QuizContext);
    const zeroResults = !state?.quiz.results?.response?.results?.length;
    const resultsTitle = zeroResults ? '' : 'Here are your results';
    if (state?.quiz.results) {
        return (React.createElement("div", { className: 'cio-results-container' },
            React.createElement("h1", { className: 'cio-results-title' }, resultsTitle),
            React.createElement("div", { className: 'cio-results-filter-and-redo-container' },
                React.createElement(ResultFilters, { hasNoResults: zeroResults }),
                React.createElement(RedoButton, null)),
            !zeroResults && (React.createElement(Results, { resultCardSalePriceKey: resultCardSalePriceKey, resultCardRegularPriceKey: resultCardRegularPriceKey, resultCardRatingCountKey: resultCardRatingCountKey, resultCardRatingScoreKey: resultCardRatingScoreKey, renderResultCardPriceDetails: renderResultCardPriceDetails })),
            zeroResults && React.createElement(ZeroResults, null)));
    }
    return (React.createElement("div", { className: 'cio-results-container' },
        React.createElement(Spinner, null)));
}

==> constructorio-ui-quizzes-1.8.2.tgz: package/lib/mjs/components/ResultContainer/ResultContainer.js <==
import React, { useContext } from 'react';
import RedoButton from '../RedoButton/RedoButton';
import QuizContext from '../CioQuiz/context';
import ResultFilters from '../ResultFilters/ResultFilters';
import ZeroResults from '../ZeroResults/ZeroResults';
import Results from '../Results/Results';
import Spinner from '../Spinner/Spinner';
export default function ResultContainer(props) {
    const { options } = props;
    const { resultCardSalePriceKey, resultCardRegularPriceKey, resultCardRatingCountKey, resultCardRatingScoreKey, renderResultCardPriceDetails, } = options;
    const { state } = useContext(QuizContext);
    const numberOfResults = state?.quiz.results?.response?.results?.length;
    const zeroResults = !numberOfResults;
    const resultsTitle = zeroResults ? '' : 'Here are your results';
    if (state?.quiz.results) {
        return (React.createElement("div", { className: 'cio-results-container' },
            React.createElement("h1", { className: 'cio-results-title' }, resultsTitle),
            React.createElement("div", { className: 'cio-results-filter-and-redo-container' },
                React.createElement(ResultFilters, { hasNoResults: zeroResults }),
                React.createElement(RedoButton, null)),
            !zeroResults && (React.createElement(React.Fragment, null,
                React.createElement("div", { className: 'cio-results-num-results' },
                    numberOfResults,
                    " ",
                    numberOfResults === 1 ? 'result' : 'results'),
                React.createElement(Results, { resultCardSalePriceKey: resultCardSalePriceKey, resultCardRegularPriceKey: resultCardRegularPriceKey, resultCardRatingCountKey: resultCardRatingCountKey, resultCardRatingScoreKey: resultCardRatingScoreKey, renderResultCardPriceDetails: renderResultCardPriceDetails }))),
            zeroResults && React.createElement(ZeroResults, null)));
    }
    return (React.createElement("div", { className: 'cio-results-container' },
        React.createElement(Spinner, null)));
}
